%define major     1.1
%define libname   %mklibname %{name} %major
%define develname %mklibname %{name} -d

Name:           opencc
Version:        1.1.9
Release:        %mkrel 1
Summary:        Simplified-Traditional Chinese Conversion
License:        ASL 2.0
Group:          System/Internationalization
URL:            https://github.com/BYVoid/OpenCC
Source0:        https://github.com/BYVoid/OpenCC/archive/ver.%{version}/%{name}-%{version}.tar.gz
Patch1:         opencc-1.0.3-ld_path.patch
Patch2:         opencc-fixes-compile.patch
BuildRequires:  cmake
BuildRequires:  doxygen
BuildRequires:  cmake(rapidjson)
BuildRequires:  pkgconfig(marisa)
BuildRequires:  pkgconfig(pybind11)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(tclap)

Provides:       bundled(darts) = 0.32

%description
OpenCC is an Open Source project for conversion between Traditional Chinese and
Simplified Chinese, which supports phrase-level conversion and regional idioms
among Mainland China, Taiwan and Hong Kong.

%package -n %libname
Summary:        Runtime library for OpenCC
Group:          System/Libraries
Requires:       %name

%description -n %libname
Runtime Libraries for OpenCC.

%package -n %develname
Summary:        Development tools for OpenCC
Group:          Development/Other
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %develname
Development tools for OpenCC.

%prep
%autosetup -p1 -n OpenCC-ver.%{version}

%build
%cmake -DBUILD_DOCUMENTATION:BOOL=ON \
       -DBUILD_PYTHON:BOOL=ON \
       -DUSE_SYSTEM_DARTS:BOOL=OFF \
       -DUSE_SYSTEM_MARISA:BOOL=ON \
       -DUSE_SYSTEM_PYBIND11:BOOL=ON \
       -DUSE_SYSTEM_RAPIDJSON:BOOL=ON \
       -DUSE_SYSTEM_TCLAP:BOOL=ON
%cmake_build

%install
%cmake_install

%files
%doc AUTHORS NEWS.md README.md
%license LICENSE
%{_bindir}/*
%{_datadir}/opencc/

%files -n %{libname}
%license LICENSE
%{_libdir}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/cmake/opencc/
%{_libdir}/pkgconfig/*.pc


%changelog
* Thu May 22 2025 ns80 <ns80> 1.1.9-1.mga10
+ Revision: 2185719
- add a patch from Fedora to try to fix building with GCC 15
- new version 1.1.9

* Fri May 31 2024 daviddavid <daviddavid> 1.1.7-2.mga10
+ Revision: 2068888
- use system tclap and pybind11

* Fri May 31 2024 daviddavid <daviddavid> 1.1.7-1.mga10
+ Revision: 2068852
- use system marisa and rapidjson
- new version: 1.1.7

* Thu Nov 24 2022 daviddavid <daviddavid> 1.1.4-1.mga9
+ Revision: 1910674
- new version: 1.1.4

* Thu Nov 24 2022 daviddavid <daviddavid> 1.1.2-3.mga9
+ Revision: 1910670
- fix library pkg name, major is now 1.1 and no more 2

* Fri Mar 18 2022 umeabot <umeabot> 1.1.2-2.mga9
+ Revision: 1798886
- Mageia 9 Mass Rebuild

* Mon Jan 31 2022 mrambo3501 <mrambo3501> 1.1.2-1.mga9
+ Revision: 1770797
- verison 1.1.2
- rediff Patch1
- delete Patch2 applied upstream

* Fri Feb 14 2020 daviddavid <daviddavid> 1.0.5-4.mga8
+ Revision: 1520220
- use new cmake macros
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Fri Nov 02 2018 mrambo3501 <mrambo3501> 1.0.5-3.mga7
+ Revision: 1327709
- add upstream patch which fixes CVE-2018-16982 (mga#23764)

* Sun Sep 23 2018 umeabot <umeabot> 1.0.5-2.mga7
+ Revision: 1299982
- Mageia 7 Mass Rebuild

* Fri Apr 13 2018 kekepower <kekepower> 1.0.5-1.mga7
+ Revision: 1218351
- Update to version 1.0.5
- Rediffed patches

* Fri Feb 12 2016 umeabot <umeabot> 1.0.3-3.mga6
+ Revision: 956514
- Mageia 6 Mass Rebuild

* Tue Aug 04 2015 fwang <fwang> 1.0.3-2.mga6
+ Revision: 860992
- bump rel
- use correct libdir
- fix cmake path
- add path
- rediff ld_path patch
- disable ldpath
- 1.0.3

* Sun Aug 02 2015 wally <wally> 1.0.2-2.mga6
+ Revision: 860763
- loosen library pkg requires

* Thu Jul 02 2015 fwang <fwang> 1.0.2-1.mga6
+ Revision: 849443
- update file list
- cleanup file list
- fix ld path
- add patch from fedora
- 1.0.2

* Thu Jun 11 2015 luigiwalser <luigiwalser> 0.4.3-5.mga5
+ Revision: 822999
- remove bogus obsoletes

* Wed Oct 15 2014 umeabot <umeabot> 0.4.3-4.mga5
+ Revision: 750296
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.4.3-3.mga5
+ Revision: 683191
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.4.3-2.mga5
+ Revision: 523631
- Mageia 4 Mass Rebuild

* Thu May 23 2013 fwang <fwang> 0.4.3-1.mga4
+ Revision: 425474
- new version 0.4.3

* Sun Jan 13 2013 umeabot <umeabot> 0.3.0-3.mga3
+ Revision: 361913
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 15 2012 tv <tv> 0.3.0-2.mga3
+ Revision: 306376
- better group & description

* Mon Jan 02 2012 fwang <fwang> 0.3.0-1.mga2
+ Revision: 189598
- new version 0.3.0

* Thu Mar 24 2011 boklm <boklm> 0.2.0-2.mga1
+ Revision: 76197
- rebuild for bug #497

* Sat Mar 12 2011 fwang <fwang> 0.2.0-1.mga1
+ Revision: 68615
- buildroot not required
- imported package opencc


* Sat Jan 29 2011 Funda Wang <fwang@mandriva.org> 0.2.0-1mdv2011.0
+ Revision: 633990
- new version 0.2.0

* Wed Oct 06 2010 Funda Wang <fwang@mandriva.org> 0.1.2-2mdv2011.0
+ Revision: 583522
- osbsoletes old package

* Fri Oct 01 2010 Funda Wang <fwang@mandriva.org> 0.1.2-1mdv2011.0
+ Revision: 582329
- update to new version 0.1.2

* Sat Aug 14 2010 Funda Wang <fwang@mandriva.org> 0.1.1-2mdv2011.0
+ Revision: 569521
- opensc is another package
- new version 0.1.1
- wrong devel name provided

* Sat Aug 14 2010 Funda Wang <fwang@mandriva.org> 0.1.0-5mdv2011.0
+ Revision: 569515
- rebuild

* Sun Aug 01 2010 Funda Wang <fwang@mandriva.org> 0.1.0-4mdv2011.0
+ Revision: 564187
- rebuild
- rebuild
- requires main package for data files
- import opencc


